@@ -307,7 +307,9 @@ def time_limit(silence):  # ~ 3600 per hour
 class ChartMixin(object):
     def get_chart_data_for_group(self, instances, max_days=90, key=None):
         if not instances:
-            return []
+            if key is None:
+                return []
+            return {}
 
         if hasattr(instances[0], '_state'):
             db = instances[0]._state.db or 'default'
@@ -334,10 +336,17 @@ class ChartMixin(object):
 
     def _get_chart_data(self, queryset, max_days=90, db='default', key=None):
         if not has_charts(db):
-            return []
+            if key is None:
+                return []
+            return {}
 
         today = timezone.now().replace(microsecond=0, second=0)
 
+        # the last interval is not accurate, so we exclude it
+        # TODO: it'd be ideal to normalize the last datapoint so that we can include it
+        # and not have ~inaccurate data for up to MINUTE_NORMALIZATION
+        today -= datetime.timedelta(minutes=settings.MINUTE_NORMALIZATION)
+
         if max_days >= 30:
             g_type = 'date'
             d_type = 'days'
@@ -353,8 +362,8 @@ class ChartMixin(object):
         else:
             g_type = 'minute'
             d_type = 'minutes'
-            points = max_days * 24 * 4
-            modifier = 15
+            modifier = settings.MINUTE_NORMALIZATION
+            points = max_days * 24 * (60 / modifier)
 
         min_date = today - datetime.timedelta(days=max_days)
 
@@ -699,16 +708,28 @@ class GroupManager(BaseManager, ChartMixin):
         if queryset is None:
             queryset = self
 
-        assert minutes >= settings.MINUTE_NORMALIZATION
+        normalization = float(settings.MINUTE_NORMALIZATION)
+        assert minutes >= normalization
 
         engine = get_db_engine(queryset.db)
+        # We technically only support mysql and postgresql, since there seems to be no standard
+        # way to get the epoch from a datetime/interval
         if engine.startswith('mysql'):
             minute_clause = "interval %s minute"
+            epoch_clause = "unix_timestamp(utc_timestamp()) - unix_timestamp(%(mcbm_tbl)s.date)"
+            now_clause = 'utc_timestamp()'
         else:
             minute_clause = "interval '%s minutes'"
+            epoch_clause = "extract(epoch from now()) - extract(epoch from %(mcbm_tbl)s.date)"
+            now_clause = 'now()'
+
+        epoch_clause = epoch_clause % dict(mcbm_tbl=mcbm_tbl)
 
         queryset = queryset.extra(
-            where=["%s.date >= now() - %s" % (mcbm_tbl, minute_clause % (minutes, ))],
+            where=[
+                "%s.date >= %s - %s" % (mcbm_tbl, now_clause, minute_clause % (minutes + 1, )),
+                "%s.date <= %s - %s" % (mcbm_tbl, now_clause, minute_clause % (1, ))
+            ],
         ).annotate(x=Sum('messagecountbyminute__times_seen')).order_by('id')
 
         sql, params = queryset.query.get_compiler(queryset.db).as_sql()
@@ -720,17 +741,19 @@ class GroupManager(BaseManager, ChartMixin):
         after_group = after_group.split(' ORDER BY ')[0]
 
         query = """
-        SELECT (SUM(%(mcbm_tbl)s.times_seen) + 1.0) / (COALESCE(z.accel, 0) + 1.0) as accel,
-               z.accel as prev_accel,
+        SELECT (SUM(%(mcbm_tbl)s.times_seen) * (%(norm)f / (%(epoch_clause)s / 60)) + 1.0) / (COALESCE(z.rate, 0) + 1.0) as accel,
+               (COALESCE(z.rate, 0) + 1.0) as prev_rate,
                %(before_where)s
-        LEFT JOIN (SELECT a.group_id, SUM(a.times_seen) / 3.0 as accel
+        LEFT JOIN (SELECT a.group_id, SUM(a.times_seen) / COUNT(a.times_seen) / %(norm)f as rate
             FROM %(mcbm_tbl)s as a
-            WHERE a.date BETWEEN now() - %(min_time)s
-            AND now() - %(min_time)s
+            WHERE a.date BETWEEN %(now)s - %(max_time)s
+            AND %(now)s - %(min_time)s
             GROUP BY a.group_id) as z
         ON z.group_id = %(mcbm_tbl)s.group_id
-        WHERE %(before_group)s
-        GROUP BY prev_accel, %(after_group)s
+        WHERE %(mcbm_tbl)s.date BETWEEN %(now)s - %(min_time)s
+        AND %(now)s - %(offset_time)s
+        AND %(before_group)s
+        GROUP BY prev_rate, %(mcbm_tbl)s.date, %(after_group)s
         HAVING SUM(%(mcbm_tbl)s.times_seen) > 0
         ORDER BY accel DESC
         """ % dict(
@@ -738,8 +761,12 @@ class GroupManager(BaseManager, ChartMixin):
             before_where=before_where,
             before_group=before_group,
             after_group=after_group,
+            offset_time=minute_clause % (1,),
             min_time=minute_clause % (minutes + 1,),
-            max_time=minute_clause % (minutes * 4,),
+            max_time=minute_clause % (minutes * (60 / normalization),),
+            norm=normalization,
+            epoch_clause=epoch_clause,
+            now=now_clause,
         )
         return RawQuerySet(self, query, params)
 
