@@ -5,11 +5,8 @@ sentry.utils.dates
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-import pytz
-
 from datetime import datetime
 from dateutil.parser import parse
-from django.conf import settings
 from django.db import connections
 
 from sentry.utils.db import get_db_engine
@@ -25,16 +22,6 @@ DATE_TRUNC_GROUPERS = {
 }
 
 
-def utc_to_local(dt):
-    tz = pytz.timezone(settings.TIME_ZONE)
-    return tz.fromutc(dt).replace(tzinfo=None)
-
-
-def local_to_utc(dt):
-    tz = pytz.timezone(settings.TIME_ZONE)
-    return tz.localize(dt).astimezone(pytz.utc).replace(tzinfo=None)
-
-
 def get_sql_date_trunc(col, db='default', grouper='hour'):
     conn = connections[db]
 
